@@ -1,9 +1,9 @@
 """Handles incoming appsync requests, invokes methods, returns responses."""
+
 import json
-from typing import Any
 from urllib.parse import unquote
 
-from moto.core.responses import TYPE_RESPONSE, BaseResponse
+from moto.core.responses import BaseResponse
 
 from .models import AppSyncBackend, appsync_backends
 
@@ -19,63 +19,7 @@ class AppSyncResponse(BaseResponse):
         """Return backend instance specific for this region."""
         return appsync_backends[self.current_account][self.region]
 
-    def graph_ql(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
-        self.setup_class(request, full_url, headers)
-        if request.method == "POST":
-            return self.create_graphql_api()
-        if request.method == "GET":
-            return self.list_graphql_apis()
-
-    def graph_ql_individual(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
-        self.setup_class(request, full_url, headers)
-        if request.method == "GET":
-            return self.get_graphql_api()
-        if request.method == "DELETE":
-            return self.delete_graphql_api()
-        if request.method == "POST":
-            return self.update_graphql_api()
-
-    def api_key(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
-        self.setup_class(request, full_url, headers)
-        if request.method == "POST":
-            return self.create_api_key()
-        if request.method == "GET":
-            return self.list_api_keys()
-
-    def schemacreation(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
-        self.setup_class(request, full_url, headers)
-        if request.method == "POST":
-            return self.start_schema_creation()
-        if request.method == "GET":
-            return self.get_schema_creation_status()
-
-    def api_key_individual(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
-        self.setup_class(request, full_url, headers)
-        if request.method == "DELETE":
-            return self.delete_api_key()
-        if request.method == "POST":
-            return self.update_api_key()
-
-    def tags(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
-        self.setup_class(request, full_url, headers)
-        if request.method == "POST":
-            return self.tag_resource()
-        if request.method == "DELETE":
-            return self.untag_resource()
-        if request.method == "GET":
-            return self.list_tags_for_resource()
-
-    def types(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
-        self.setup_class(request, full_url, headers)
-        if request.method == "GET":
-            return self.get_type()
-
-    def schema(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
-        self.setup_class(request, full_url, headers)
-        if request.method == "GET":
-            return self.get_introspection_schema()
-
-    def create_graphql_api(self) -> TYPE_RESPONSE:
+    def create_graphql_api(self) -> str:
         params = json.loads(self.body)
         name = params.get("name")
         log_config = params.get("logConfig")
@@ -101,22 +45,22 @@ class AppSyncResponse(BaseResponse):
         )
         response = graphql_api.to_json()
         response["tags"] = self.appsync_backend.list_tags_for_resource(graphql_api.arn)
-        return 200, {}, json.dumps(dict(graphqlApi=response))
+        return json.dumps(dict(graphqlApi=response))
 
-    def get_graphql_api(self) -> TYPE_RESPONSE:
+    def get_graphql_api(self) -> str:
         api_id = self.path.split("/")[-1]
 
         graphql_api = self.appsync_backend.get_graphql_api(api_id=api_id)
         response = graphql_api.to_json()
         response["tags"] = self.appsync_backend.list_tags_for_resource(graphql_api.arn)
-        return 200, {}, json.dumps(dict(graphqlApi=response))
+        return json.dumps(dict(graphqlApi=response))
 
-    def delete_graphql_api(self) -> TYPE_RESPONSE:
+    def delete_graphql_api(self) -> str:
         api_id = self.path.split("/")[-1]
         self.appsync_backend.delete_graphql_api(api_id=api_id)
-        return 200, {}, json.dumps(dict())
+        return "{}"
 
-    def update_graphql_api(self) -> TYPE_RESPONSE:
+    def update_graphql_api(self) -> str:
         api_id = self.path.split("/")[-1]
 
         params = json.loads(self.body)
@@ -142,17 +86,13 @@ class AppSyncResponse(BaseResponse):
             xray_enabled=xray_enabled,
             lambda_authorizer_config=lambda_authorizer_config,
         )
-        return 200, {}, json.dumps(dict(graphqlApi=api.to_json()))
+        return json.dumps(dict(graphqlApi=api.to_json()))
 
-    def list_graphql_apis(self) -> TYPE_RESPONSE:
+    def list_graphql_apis(self) -> str:
         graphql_apis = self.appsync_backend.list_graphql_apis()
-        return (
-            200,
-            {},
-            json.dumps(dict(graphqlApis=[api.to_json() for api in graphql_apis])),
-        )
+        return json.dumps(dict(graphqlApis=[api.to_json() for api in graphql_apis]))
 
-    def create_api_key(self) -> TYPE_RESPONSE:
+    def create_api_key(self) -> str:
         params = json.loads(self.body)
         # /v1/apis/[api_id]/apikeys
         api_id = self.path.split("/")[-2]
@@ -161,21 +101,21 @@ class AppSyncResponse(BaseResponse):
         api_key = self.appsync_backend.create_api_key(
             api_id=api_id, description=description, expires=expires
         )
-        return 200, {}, json.dumps(dict(apiKey=api_key.to_json()))
+        return json.dumps(dict(apiKey=api_key.to_json()))
 
-    def delete_api_key(self) -> TYPE_RESPONSE:
+    def delete_api_key(self) -> str:
         api_id = self.path.split("/")[-3]
         api_key_id = self.path.split("/")[-1]
         self.appsync_backend.delete_api_key(api_id=api_id, api_key_id=api_key_id)
-        return 200, {}, json.dumps(dict())
+        return "{}"
 
-    def list_api_keys(self) -> TYPE_RESPONSE:
+    def list_api_keys(self) -> str:
         # /v1/apis/[api_id]/apikeys
         api_id = self.path.split("/")[-2]
         api_keys = self.appsync_backend.list_api_keys(api_id=api_id)
-        return 200, {}, json.dumps(dict(apiKeys=[key.to_json() for key in api_keys]))
+        return json.dumps(dict(apiKeys=[key.to_json() for key in api_keys]))
 
-    def update_api_key(self) -> TYPE_RESPONSE:
+    def update_api_key(self) -> str:
         api_id = self.path.split("/")[-3]
         api_key_id = self.path.split("/")[-1]
         params = json.loads(self.body)
@@ -187,57 +127,57 @@ class AppSyncResponse(BaseResponse):
             description=description,
             expires=expires,
         )
-        return 200, {}, json.dumps(dict(apiKey=api_key.to_json()))
+        return json.dumps(dict(apiKey=api_key.to_json()))
 
-    def start_schema_creation(self) -> TYPE_RESPONSE:
+    def start_schema_creation(self) -> str:
         params = json.loads(self.body)
         api_id = self.path.split("/")[-2]
         definition = params.get("definition")
         status = self.appsync_backend.start_schema_creation(
             api_id=api_id, definition=definition
         )
-        return 200, {}, json.dumps({"status": status})
+        return json.dumps({"status": status})
 
-    def get_schema_creation_status(self) -> TYPE_RESPONSE:
+    def get_schema_creation_status(self) -> str:
         api_id = self.path.split("/")[-2]
         status, details = self.appsync_backend.get_schema_creation_status(api_id=api_id)
-        return 200, {}, json.dumps(dict(status=status, details=details))
+        return json.dumps(dict(status=status, details=details))
 
-    def tag_resource(self) -> TYPE_RESPONSE:
+    def tag_resource(self) -> str:
         resource_arn = self._extract_arn_from_path()
         params = json.loads(self.body)
         tags = params.get("tags")
         self.appsync_backend.tag_resource(resource_arn=resource_arn, tags=tags)
-        return 200, {}, json.dumps(dict())
+        return "{}"
 
-    def untag_resource(self) -> TYPE_RESPONSE:
+    def untag_resource(self) -> str:
         resource_arn = self._extract_arn_from_path()
         tag_keys = self.querystring.get("tagKeys", [])
         self.appsync_backend.untag_resource(
             resource_arn=resource_arn, tag_keys=tag_keys
         )
-        return 200, {}, json.dumps(dict())
+        return "{}"
 
-    def list_tags_for_resource(self) -> TYPE_RESPONSE:
+    def list_tags_for_resource(self) -> str:
         resource_arn = self._extract_arn_from_path()
         tags = self.appsync_backend.list_tags_for_resource(resource_arn=resource_arn)
-        return 200, {}, json.dumps(dict(tags=tags))
+        return json.dumps(dict(tags=tags))
 
     def _extract_arn_from_path(self) -> str:
         # /v1/tags/arn_that_may_contain_a_slash
         path = unquote(self.path)
         return "/".join(path.split("/")[3:])
 
-    def get_type(self) -> TYPE_RESPONSE:
+    def get_type(self) -> str:
         api_id = unquote(self.path.split("/")[-3])
         type_name = self.path.split("/")[-1]
         type_format = self.querystring.get("format")[0]  # type: ignore[index]
         graphql_type = self.appsync_backend.get_type(
             api_id=api_id, type_name=type_name, type_format=type_format
         )
-        return 200, {}, json.dumps(dict(type=graphql_type))
+        return json.dumps(dict(type=graphql_type))
 
-    def get_introspection_schema(self) -> TYPE_RESPONSE:
+    def get_introspection_schema(self) -> str:
         api_id = self.path.split("/")[-2]
         format_ = self.querystring.get("format")[0]  # type: ignore[index]
         if self.querystring.get("includeDirectives"):
@@ -251,4 +191,61 @@ class AppSyncResponse(BaseResponse):
         schema = graphql_schema.get_introspection_schema(
             format_=format_, include_directives=include_directives
         )
-        return 200, {}, schema
+        return schema
+
+    def get_api_cache(self) -> str:
+        api_id = self.path.split("/")[-2]
+        api_cache = self.appsync_backend.get_api_cache(
+            api_id=api_id,
+        )
+        return json.dumps(dict(apiCache=api_cache.to_json()))
+
+    def delete_api_cache(self) -> str:
+        api_id = self.path.split("/")[-2]
+        self.appsync_backend.delete_api_cache(
+            api_id=api_id,
+        )
+        return "{}"
+
+    def create_api_cache(self) -> str:
+        params = json.loads(self.body)
+        api_id = self.path.split("/")[-2]
+        ttl = params.get("ttl")
+        transit_encryption_enabled = params.get("transitEncryptionEnabled")
+        at_rest_encryption_enabled = params.get("atRestEncryptionEnabled")
+        api_caching_behavior = params.get("apiCachingBehavior")
+        type = params.get("type")
+        health_metrics_config = params.get("healthMetricsConfig")
+        api_cache = self.appsync_backend.create_api_cache(
+            api_id=api_id,
+            ttl=ttl,
+            transit_encryption_enabled=transit_encryption_enabled,
+            at_rest_encryption_enabled=at_rest_encryption_enabled,
+            api_caching_behavior=api_caching_behavior,
+            type=type,
+            health_metrics_config=health_metrics_config,
+        )
+        return json.dumps(dict(apiCache=api_cache.to_json()))
+
+    def update_api_cache(self) -> str:
+        api_id = self.path.split("/")[-3]
+        params = json.loads(self.body)
+        ttl = params.get("ttl")
+        api_caching_behavior = params.get("apiCachingBehavior")
+        type = params.get("type")
+        health_metrics_config = params.get("healthMetricsConfig")
+        api_cache = self.appsync_backend.update_api_cache(
+            api_id=api_id,
+            ttl=ttl,
+            api_caching_behavior=api_caching_behavior,
+            type=type,
+            health_metrics_config=health_metrics_config,
+        )
+        return json.dumps(dict(apiCache=api_cache.to_json()))
+
+    def flush_api_cache(self) -> str:
+        api_id = self.path.split("/")[-2]
+        self.appsync_backend.flush_api_cache(
+            api_id=api_id,
+        )
+        return "{}"
