@@ -1,65 +1,63 @@
 """Implementation of the AWS Config Service APIs."""
+
 import json
 import re
 import time
-
 from datetime import datetime
 from typing import Any, Dict, List, Optional, Union
 
 from moto.config.exceptions import (
-    InvalidResourceTypeException,
-    InvalidDeliveryFrequency,
+    DuplicateTags,
+    InsufficientPermissionsException,
     InvalidConfigurationRecorderNameException,
-    NameTooLongException,
-    MaxNumberOfConfigurationRecordersExceededException,
-    InvalidRecordingGroupException,
-    NoSuchConfigurationRecorderException,
-    NoAvailableConfigurationRecorderException,
     InvalidDeliveryChannelNameException,
-    NoSuchBucketException,
+    InvalidDeliveryFrequency,
+    InvalidLimitException,
+    InvalidNextTokenException,
+    InvalidParameterValueException,
+    InvalidRecordingGroupException,
+    InvalidResourceParameters,
+    InvalidResourceTypeException,
+    InvalidResultTokenException,
     InvalidS3KeyPrefixException,
     InvalidS3KmsKeyArnException,
     InvalidSNSTopicARNException,
-    MaxNumberOfDeliveryChannelsExceededException,
-    NoAvailableDeliveryChannelException,
-    NoSuchDeliveryChannelException,
-    LastDeliveryChannelDeleteFailedException,
-    TagKeyTooBig,
-    TooManyTags,
-    TagValueTooBig,
-    TooManyAccountSources,
-    InvalidParameterValueException,
-    InvalidNextTokenException,
-    NoSuchConfigurationAggregatorException,
     InvalidTagCharacters,
-    DuplicateTags,
-    InvalidLimitException,
-    InvalidResourceParameters,
-    TooManyResourceIds,
-    ResourceNotDiscoveredException,
-    ResourceNotFoundException,
-    TooManyResourceKeys,
-    InvalidResultTokenException,
-    ValidationException,
-    NoSuchOrganizationConformancePackException,
+    LastDeliveryChannelDeleteFailedException,
     MaxNumberOfConfigRulesExceededException,
-    InsufficientPermissionsException,
+    MaxNumberOfConfigurationRecordersExceededException,
+    MaxNumberOfDeliveryChannelsExceededException,
+    MissingRequiredConfigRuleParameterException,
+    NameTooLongException,
+    NoAvailableConfigurationRecorderException,
+    NoAvailableDeliveryChannelException,
+    NoSuchBucketException,
     NoSuchConfigRuleException,
+    NoSuchConfigurationAggregatorException,
+    NoSuchConfigurationRecorderException,
+    NoSuchDeliveryChannelException,
+    NoSuchOrganizationConformancePackException,
     NoSuchRetentionConfigurationException,
     ResourceInUseException,
-    MissingRequiredConfigRuleParameterException,
+    ResourceNotDiscoveredException,
+    ResourceNotFoundException,
+    TagKeyTooBig,
+    TagValueTooBig,
+    TooManyAccountSources,
+    TooManyResourceIds,
+    TooManyResourceKeys,
+    TooManyTags,
+    ValidationException,
 )
-
-from moto.core import BaseBackend, BackendDict, BaseModel
-from moto.core.common_models import ConfigQueryModel
+from moto.core.base_backend import BackendDict, BaseBackend
+from moto.core.common_models import BaseModel, ConfigQueryModel
 from moto.core.responses import AWSServiceSpec
 from moto.core.utils import utcnow
-from moto.iam.config import role_config_query, policy_config_query
+from moto.iam.config import policy_config_query, role_config_query
 from moto.moto_api._internal import mock_random as random
 from moto.s3.config import s3_config_query
 from moto.s3control.config import s3_account_public_access_block_query
-from moto.utilities.utils import load_resource
-
+from moto.utilities.utils import get_partition, load_resource
 
 POP_STRINGS = [
     "capitalizeStart",
@@ -73,7 +71,7 @@ DEFAULT_PAGE_SIZE = 100
 CONFIG_RULE_PAGE_SIZE = 25
 
 # Map the Config resource type to a backend:
-RESOURCE_MAP: Dict[str, ConfigQueryModel] = {
+RESOURCE_MAP: Dict[str, ConfigQueryModel[Any]] = {
     "AWS::S3::Bucket": s3_config_query,
     "AWS::S3::AccountPublicAccessBlock": s3_account_public_access_block_query,
     "AWS::IAM::Role": role_config_query,
@@ -402,7 +400,7 @@ class ConfigAggregator(ConfigEmptyDictable):
         super().__init__(capitalize_start=True, capitalize_arn=False)
 
         self.configuration_aggregator_name = name
-        self.configuration_aggregator_arn = f"arn:aws:config:{region}:{account_id}:config-aggregator/config-aggregator-{random_string()}"
+        self.configuration_aggregator_arn = f"arn:{get_partition(region)}:config:{region}:{account_id}:config-aggregator/config-aggregator-{random_string()}"
         self.account_aggregation_sources = account_sources
         self.organization_aggregation_source = org_source
         self.creation_time = datetime2int(utcnow())
@@ -440,7 +438,7 @@ class ConfigAggregationAuthorization(ConfigEmptyDictable):
     ):
         super().__init__(capitalize_start=True, capitalize_arn=False)
 
-        self.aggregation_authorization_arn = f"arn:aws:config:{current_region}:{account_id}:aggregation-authorization/{authorized_account_id}/{authorized_aws_region}"
+        self.aggregation_authorization_arn = f"arn:{get_partition(current_region)}:config:{current_region}:{account_id}:aggregation-authorization/{authorized_account_id}/{authorized_aws_region}"
         self.authorized_account_id = authorized_account_id
         self.authorized_aws_region = authorized_aws_region
         self.creation_time = datetime2int(utcnow())
@@ -470,7 +468,7 @@ class OrganizationConformancePack(ConfigEmptyDictable):
         self.delivery_s3_key_prefix = delivery_s3_key_prefix
         self.excluded_accounts = excluded_accounts or []
         self.last_update_time = datetime2int(utcnow())
-        self.organization_conformance_pack_arn = f"arn:aws:config:{region}:{account_id}:organization-conformance-pack/{self._unique_pack_name}"
+        self.organization_conformance_pack_arn = f"arn:{get_partition(region)}:config:{region}:{account_id}:organization-conformance-pack/{self._unique_pack_name}"
         self.organization_conformance_pack_name = name
 
     def update(
@@ -490,7 +488,6 @@ class OrganizationConformancePack(ConfigEmptyDictable):
 
 
 class Scope(ConfigEmptyDictable):
-
     """Defines resources that can trigger an evaluation for the rule.
 
     Per boto3 documentation, Scope can be one of:
@@ -539,7 +536,6 @@ class Scope(ConfigEmptyDictable):
 
 
 class SourceDetail(ConfigEmptyDictable):
-
     """Source and type of event triggering AWS Config resource evaluation.
 
     Applies only to customer rules.
@@ -636,7 +632,6 @@ class SourceDetail(ConfigEmptyDictable):
 
 
 class Source(ConfigEmptyDictable):
-
     """Defines rule owner, id and notification for triggering evaluation."""
 
     OWNERS = {"AWS", "CUSTOM_LAMBDA"}
@@ -687,10 +682,10 @@ class Source(ConfigEmptyDictable):
 
         # Import is slow and as it's not needed for all config service
         # operations, only load it if needed.
-        from moto.awslambda import lambda_backends
+        from moto.awslambda.utils import get_backend
 
         try:
-            lambda_backends[account_id][region].get_function(source_identifier)
+            get_backend(account_id, region).get_function(source_identifier)
         except Exception:
             raise InsufficientPermissionsException(
                 f"The AWS Lambda function {source_identifier} cannot be "
@@ -716,7 +711,6 @@ class Source(ConfigEmptyDictable):
 
 
 class ConfigRule(ConfigEmptyDictable):
-
     """AWS Config Rule to evaluate compliance of resources to configuration.
 
     Can be a managed or custom config rule.  Contains the instantiations of
@@ -747,9 +741,7 @@ class ConfigRule(ConfigEmptyDictable):
         self.maximum_execution_frequency = None  # keeps pylint happy
         self.modify_fields(region, config_rule, tags)
         self.config_rule_id = f"config-rule-{random_string():.6}"
-        self.config_rule_arn = (
-            f"arn:aws:config:{region}:{account_id}:config-rule/{self.config_rule_id}"
-        )
+        self.config_rule_arn = f"arn:{get_partition(region)}:config:{region}:{account_id}:config-rule/{self.config_rule_id}"
 
     def modify_fields(
         self, region: str, config_rule: Dict[str, Any], tags: Dict[str, str]
@@ -923,13 +915,6 @@ class ConfigBackend(BaseBackend):
         self.config_schema: Optional[AWSServiceSpec] = None
         self.retention_configuration: Optional[RetentionConfiguration] = None
 
-    @staticmethod
-    def default_vpc_endpoint_service(service_region: str, zones: List[str]) -> List[Dict[str, Any]]:  # type: ignore[misc]
-        """List of dicts representing default VPC endpoints for this service."""
-        return BaseBackend.default_vpc_endpoint_service_factory(
-            service_region, zones, "config"
-        )
-
     def _validate_resource_types(self, resource_list: List[str]) -> None:
         if not self.config_schema:
             self.config_schema = AWSServiceSpec(
@@ -1462,7 +1447,6 @@ class ConfigBackend(BaseBackend):
     def list_discovered_resources(
         self,
         resource_type: str,
-        backend_region: str,
         resource_ids: List[str],
         resource_name: str,
         limit: int,
@@ -1498,14 +1482,19 @@ class ConfigBackend(BaseBackend):
         # moto, then call upon the resource type's Config Query class to
         # retrieve the list of resources that match the criteria:
         if RESOURCE_MAP.get(resource_type, {}):
-            # Is this a global resource type? -- if so, re-write the region to 'global':
-            backend_query_region = (
-                backend_region  # Always provide the backend this request arrived from.
-            )
-            if RESOURCE_MAP[resource_type].backends[self.account_id].get("global"):
-                backend_region = "global"
+            # Always provide the backend this request arrived from.
+            backend_query_region = self.region_name
+            # Is this a global resource type? -- if so, use the partition
+            if (
+                RESOURCE_MAP[resource_type]
+                .backends[self.account_id]
+                .get(self.partition)
+            ):
+                backend_region = self.partition
+            else:
+                backend_region = self.region_name
 
-            # For non-aggregated queries, the we only care about the
+            # For non-aggregated queries, we only care about the
             # backend_region. Need to verify that moto has implemented
             # the region for the given backend:
             if (
@@ -1518,10 +1507,11 @@ class ConfigBackend(BaseBackend):
                     resource_type
                 ].list_config_service_resources(
                     self.account_id,
-                    resource_ids,
-                    resource_name,
-                    limit,
-                    next_token,
+                    partition=self.partition,
+                    resource_ids=resource_ids,
+                    resource_name=resource_name,
+                    limit=limit,
+                    next_token=next_token,
                     backend_region=backend_query_region,
                 )
 
@@ -1588,10 +1578,11 @@ class ConfigBackend(BaseBackend):
                 resource_type
             ].list_config_service_resources(
                 self.account_id,
-                resource_id,
-                resource_name,
-                limit,
-                next_token,
+                partition=self.partition,
+                resource_ids=resource_id,
+                resource_name=resource_name,
+                limit=limit,
+                next_token=next_token,
                 resource_region=resource_region,
                 aggregator=self.config_aggregators.get(aggregator_name).__dict__,
             )
@@ -1634,12 +1625,12 @@ class ConfigBackend(BaseBackend):
         if resource_type not in RESOURCE_MAP:
             raise ResourceNotDiscoveredException(resource_type, resource_id)
 
+        # Always provide the backend this request arrived from.
+        backend_query_region = backend_region
         # Is the resource type global?
-        backend_query_region = (
-            backend_region  # Always provide the backend this request arrived from.
-        )
-        if RESOURCE_MAP[resource_type].backends[self.account_id].get("global"):
-            backend_region = "global"
+        partition = get_partition(backend_region)
+        if RESOURCE_MAP[resource_type].backends[self.account_id].get(partition):
+            backend_region = partition
 
         # If the backend region isn't implemented then we won't find the item:
         if (
@@ -1651,7 +1642,10 @@ class ConfigBackend(BaseBackend):
 
         # Get the item:
         item = RESOURCE_MAP[resource_type].get_config_resource(
-            self.account_id, resource_id, backend_region=backend_query_region
+            account_id=self.account_id,
+            partition=self.partition,
+            resource_id=resource_id,
+            backend_region=backend_query_region,
         )
         if not item:
             raise ResourceNotDiscoveredException(resource_type, resource_id)
@@ -1683,17 +1677,17 @@ class ConfigBackend(BaseBackend):
                 # Not found so skip.
                 continue
 
-            # Is the resource type global?
             config_backend_region = backend_region
-            backend_query_region = (
-                backend_region  # Always provide the backend this request arrived from.
-            )
+            # Always provide the backend this request arrived from.
+            backend_query_region = backend_region
+            # Is the resource type global?
+            partition = get_partition(backend_region)
             if (
                 RESOURCE_MAP[resource["resourceType"]]
                 .backends[self.account_id]
-                .get("global")
+                .get(partition)
             ):
-                config_backend_region = "global"
+                config_backend_region = partition
 
             # If the backend region isn't implemented then we won't find the item:
             if (
@@ -1706,7 +1700,8 @@ class ConfigBackend(BaseBackend):
             # Get the item:
             item = RESOURCE_MAP[resource["resourceType"]].get_config_resource(
                 self.account_id,
-                resource["resourceId"],
+                partition=self.partition,
+                resource_id=resource["resourceId"],
                 backend_region=backend_query_region,
             )
             if not item:
@@ -1761,7 +1756,8 @@ class ConfigBackend(BaseBackend):
             # Get the item:
             item = RESOURCE_MAP[resource_type].get_config_resource(
                 self.account_id,
-                resource_id,
+                partition=self.partition,
+                resource_id=resource_id,
                 resource_name=resource_name,
                 resource_region=resource_region,
             )
