@@ -1,6 +1,7 @@
 from typing import Any, Dict, List, Optional
 
 from ..exceptions import (
+    DependencyViolationError,
     InvalidNetworkAclIdError,
     InvalidRouteTableIdError,
     NetworkAclEntryAlreadyExistsError,
@@ -61,6 +62,14 @@ class NetworkAclBackend:
             )
 
     def delete_network_acl(self, network_acl_id: str) -> "NetworkAcl":
+        if any(
+            network_acl.id == network_acl_id and len(network_acl.associations) > 0
+            for network_acl in self.network_acls.values()
+        ):
+            raise DependencyViolationError(
+                f"The network ACL '{network_acl_id}' has dependencies and cannot be deleted."
+            )
+
         deleted = self.network_acls.pop(network_acl_id, None)
         if not deleted:
             raise InvalidNetworkAclIdError(network_acl_id)
@@ -79,7 +88,6 @@ class NetworkAclBackend:
         port_range_from: Optional[int],
         port_range_to: Optional[int],
     ) -> "NetworkAclEntry":
-
         network_acl = self.get_network_acl(network_acl_id)
         if any(
             entry.egress == egress and entry.rule_number == rule_number
@@ -129,7 +137,6 @@ class NetworkAclBackend:
         port_range_from: int,
         port_range_to: int,
     ) -> "NetworkAclEntry":
-
         self.delete_network_acl_entry(network_acl_id, rule_number, egress)
         network_acl_entry = self.create_network_acl_entry(
             network_acl_id,
@@ -148,7 +155,6 @@ class NetworkAclBackend:
     def replace_network_acl_association(
         self, association_id: str, network_acl_id: str
     ) -> "NetworkAclAssociation":
-
         # lookup existing association for subnet and delete it
         default_acl = next(
             value
