@@ -19,11 +19,15 @@ class ElasticBlockStore(EC2BaseResponse):
         description = self._get_param("Description")
         tags = self._parse_tag_specification()
         snapshot_tags = tags.get("snapshot", {})
+        kms_key_id = self._get_param("KmsKeyId")
 
         self.error_on_dryrun()
 
         snapshot = self.ec2_backend.copy_snapshot(
-            source_snapshot_id, source_region, description
+            source_snapshot_id=source_snapshot_id,
+            source_region=source_region,
+            description=description,
+            kms_key_id=kms_key_id,
         )
         snapshot.add_tags(snapshot_tags)
         template = self.response_template(COPY_SNAPSHOT_RESPONSE)
@@ -67,6 +71,7 @@ class ElasticBlockStore(EC2BaseResponse):
         encrypted = self._get_bool_param("Encrypted", if_none=False)
         kms_key_id = self._get_param("KmsKeyId")
         iops = self._get_param("Iops")
+        throughput = self._get_param("Throughput")
 
         self.error_on_dryrun()
 
@@ -78,6 +83,7 @@ class ElasticBlockStore(EC2BaseResponse):
             kms_key_id=kms_key_id,
             volume_type=volume_type,
             iops=iops,
+            throughput=throughput,
         )
         volume.add_tags(volume_tags)
         template = self.response_template(CREATE_VOLUME_RESPONSE)
@@ -246,6 +252,9 @@ CREATE_VOLUME_RESPONSE = """<CreateVolumeResponse xmlns="http://ec2.amazonaws.co
   {% if volume.iops %}
     <iops>{{ volume.iops }}</iops>
   {% endif %}
+  {% if volume.throughput %}
+    <throughput>{{ volume.throughput }}</throughput>
+  {% endif %}
 </CreateVolumeResponse>"""
 
 DESCRIBE_VOLUMES_RESPONSE = """<DescribeVolumesResponse xmlns="http://ec2.amazonaws.com/doc/2013-10-15/">
@@ -295,6 +304,9 @@ DESCRIBE_VOLUMES_RESPONSE = """<DescribeVolumesResponse xmlns="http://ec2.amazon
              {% if volume.iops %}
                <iops>{{ volume.iops }}</iops>
              {% endif %}
+             {% if volume.throughput %}
+               <throughput>{{ volume.throughput }}</throughput>
+             {% endif %}
           </item>
       {% endfor %}
    </volumeSet>
@@ -404,6 +416,7 @@ DESCRIBE_SNAPSHOTS_RESPONSE = """<DescribeSnapshotsResponse xmlns="http://ec2.am
             <volumeSize>{{ snapshot.volume.size }}</volumeSize>
              <description>{{ snapshot.description }}</description>
              <encrypted>{{ 'true' if snapshot.encrypted else 'false' }}</encrypted>
+             {% if snapshot.kms_key_id %}<kmsKeyId>{{ snapshot.kms_key_id }}</kmsKeyId>{% endif %}
              <tagSet>
                {% for tag in snapshot.get_tags() %}
                  <item>
