@@ -1,9 +1,8 @@
 from moto.core.exceptions import RESTError
 from moto.core.responses import BaseResponse
-from moto.utilities.aws_headers import amzn_request_id
-from .models import elbv2_backends, ELBv2Backend
-from .exceptions import TargetGroupNotFoundError
-from .exceptions import ListenerOrBalancerMissingError
+
+from .exceptions import ListenerOrBalancerMissingError, TargetGroupNotFoundError
+from .models import ELBv2Backend, elbv2_backends
 
 SSL_POLICIES = [
     {
@@ -375,7 +374,6 @@ class ELBV2Response(BaseResponse):
     def elbv2_backend(self) -> ELBv2Backend:
         return elbv2_backends[self.current_account][self.region]
 
-    @amzn_request_id
     def create_load_balancer(self) -> str:
         params = self._get_params()
         load_balancer_name = params.get("Name")
@@ -398,7 +396,6 @@ class ELBV2Response(BaseResponse):
         template = self.response_template(CREATE_LOAD_BALANCER_TEMPLATE)
         return template.render(load_balancer=load_balancer)
 
-    @amzn_request_id
     def create_rule(self) -> str:
         params = self._get_params()
         rules = self.elbv2_backend.create_rule(
@@ -412,7 +409,6 @@ class ELBV2Response(BaseResponse):
         template = self.response_template(CREATE_RULE_TEMPLATE)
         return template.render(rules=rules)
 
-    @amzn_request_id
     def create_target_group(self) -> str:
         params = self._get_params()
         name = params.get("Name")
@@ -456,7 +452,6 @@ class ELBV2Response(BaseResponse):
         template = self.response_template(CREATE_TARGET_GROUP_TEMPLATE)
         return template.render(target_group=target_group)
 
-    @amzn_request_id
     def create_listener(self) -> str:
         params = self._get_params()
         load_balancer_arn = self._get_param("LoadBalancerArn")
@@ -486,7 +481,6 @@ class ELBV2Response(BaseResponse):
         template = self.response_template(CREATE_LISTENER_TEMPLATE)
         return template.render(listener=listener)
 
-    @amzn_request_id
     def describe_load_balancers(self) -> str:
         arns = self._get_multi_param("LoadBalancerArns.member")
         names = self._get_multi_param("Names.member")
@@ -510,7 +504,6 @@ class ELBV2Response(BaseResponse):
         template = self.response_template(DESCRIBE_LOAD_BALANCERS_TEMPLATE)
         return template.render(load_balancers=load_balancers_resp, marker=next_marker)
 
-    @amzn_request_id
     def describe_rules(self) -> str:
         listener_arn = self._get_param("ListenerArn")
         rule_arns = (
@@ -539,7 +532,6 @@ class ELBV2Response(BaseResponse):
         template = self.response_template(DESCRIBE_RULES_TEMPLATE)
         return template.render(rules=rules_resp, marker=next_marker)
 
-    @amzn_request_id
     def describe_target_groups(self) -> str:
         load_balancer_arn = self._get_param("LoadBalancerArn")
         target_group_arns = self._get_multi_param("TargetGroupArns.member")
@@ -551,7 +543,6 @@ class ELBV2Response(BaseResponse):
         template = self.response_template(DESCRIBE_TARGET_GROUPS_TEMPLATE)
         return template.render(target_groups=target_groups)
 
-    @amzn_request_id
     def describe_target_group_attributes(self) -> str:
         target_group_arn = self._get_param("TargetGroupArn")
         target_group = self.elbv2_backend.target_groups.get(target_group_arn)
@@ -560,7 +551,6 @@ class ELBV2Response(BaseResponse):
         template = self.response_template(DESCRIBE_TARGET_GROUP_ATTRIBUTES_TEMPLATE)
         return template.render(attributes=target_group.attributes)
 
-    @amzn_request_id
     def describe_listeners(self) -> str:
         load_balancer_arn = self._get_param("LoadBalancerArn")
         listener_arns = self._get_multi_param("ListenerArns.member")
@@ -573,35 +563,30 @@ class ELBV2Response(BaseResponse):
         template = self.response_template(DESCRIBE_LISTENERS_TEMPLATE)
         return template.render(listeners=listeners)
 
-    @amzn_request_id
     def delete_load_balancer(self) -> str:
         arn = self._get_param("LoadBalancerArn")
         self.elbv2_backend.delete_load_balancer(arn)
         template = self.response_template(DELETE_LOAD_BALANCER_TEMPLATE)
         return template.render()
 
-    @amzn_request_id
     def delete_rule(self) -> str:
         arn = self._get_param("RuleArn")
         self.elbv2_backend.delete_rule(arn)
         template = self.response_template(DELETE_RULE_TEMPLATE)
         return template.render()
 
-    @amzn_request_id
     def delete_target_group(self) -> str:
         arn = self._get_param("TargetGroupArn")
         self.elbv2_backend.delete_target_group(arn)
         template = self.response_template(DELETE_TARGET_GROUP_TEMPLATE)
         return template.render()
 
-    @amzn_request_id
     def delete_listener(self) -> str:
         arn = self._get_param("ListenerArn")
         self.elbv2_backend.delete_listener(arn)
         template = self.response_template(DELETE_LISTENER_TEMPLATE)
         return template.render()
 
-    @amzn_request_id
     def modify_rule(self) -> str:
         rule_arn = self._get_param("RuleArn")
         params = self._get_params()
@@ -613,7 +598,6 @@ class ELBV2Response(BaseResponse):
         template = self.response_template(MODIFY_RULE_TEMPLATE)
         return template.render(rules=rules)
 
-    @amzn_request_id
     def modify_target_group_attributes(self) -> str:
         target_group_arn = self._get_param("TargetGroupArn")
         attrs = self._get_list_prefix("Attributes.member")
@@ -623,7 +607,6 @@ class ELBV2Response(BaseResponse):
         template = self.response_template(MODIFY_TARGET_GROUP_ATTRIBUTES_TEMPLATE)
         return template.render(attributes=attributes)
 
-    @amzn_request_id
     def register_targets(self) -> str:
         target_group_arn = self._get_param("TargetGroupArn")
         targets = self._get_list_prefix("Targets.member")
@@ -632,7 +615,6 @@ class ELBV2Response(BaseResponse):
         template = self.response_template(REGISTER_TARGETS_TEMPLATE)
         return template.render()
 
-    @amzn_request_id
     def deregister_targets(self) -> str:
         target_group_arn = self._get_param("TargetGroupArn")
         targets = self._get_list_prefix("Targets.member")
@@ -641,7 +623,6 @@ class ELBV2Response(BaseResponse):
         template = self.response_template(DEREGISTER_TARGETS_TEMPLATE)
         return template.render()
 
-    @amzn_request_id
     def describe_target_health(self) -> str:
         target_group_arn = self._get_param("TargetGroupArn")
         targets = self._get_list_prefix("Targets.member")
@@ -652,7 +633,6 @@ class ELBV2Response(BaseResponse):
         template = self.response_template(DESCRIBE_TARGET_HEALTH_TEMPLATE)
         return template.render(target_health_descriptions=target_health_descriptions)
 
-    @amzn_request_id
     def set_rule_priorities(self) -> str:
         rule_priorities = self._get_list_prefix("RulePriorities.member")
         for rule_priority in rule_priorities:
@@ -661,7 +641,6 @@ class ELBV2Response(BaseResponse):
         template = self.response_template(SET_RULE_PRIORITIES_TEMPLATE)
         return template.render(rules=rules)
 
-    @amzn_request_id
     def add_tags(self) -> str:
         resource_arns = self._get_multi_param("ResourceArns.member")
         tags = self._get_params().get("Tags")
@@ -671,7 +650,6 @@ class ELBV2Response(BaseResponse):
         template = self.response_template(ADD_TAGS_TEMPLATE)
         return template.render()
 
-    @amzn_request_id
     def remove_tags(self) -> str:
         resource_arns = self._get_multi_param("ResourceArns.member")
         tag_keys = self._get_multi_param("TagKeys.member")
@@ -681,7 +659,6 @@ class ELBV2Response(BaseResponse):
         template = self.response_template(REMOVE_TAGS_TEMPLATE)
         return template.render()
 
-    @amzn_request_id
     def describe_tags(self) -> str:
         resource_arns = self._get_multi_param("ResourceArns.member")
         resource_tags = self.elbv2_backend.describe_tags(resource_arns)
@@ -689,7 +666,6 @@ class ELBV2Response(BaseResponse):
         template = self.response_template(DESCRIBE_TAGS_TEMPLATE)
         return template.render(resource_tags=resource_tags)
 
-    @amzn_request_id
     def describe_account_limits(self) -> str:
         # Supports paging but not worth implementing yet
         # marker = self._get_param('Marker')
@@ -704,12 +680,12 @@ class ELBV2Response(BaseResponse):
             "network-load-balancers": 20,
             "targets-per-network-load-balancer": 200,
             "listeners-per-network-load-balancer": 50,
+            "certificates-per-application-load-balancer": 25,
         }
 
         template = self.response_template(DESCRIBE_LIMITS_TEMPLATE)
         return template.render(limits=limits)
 
-    @amzn_request_id
     def describe_ssl_policies(self) -> str:
         names = self._get_multi_param("Names.member.")
         # Supports paging but not worth implementing yet
@@ -723,7 +699,6 @@ class ELBV2Response(BaseResponse):
         template = self.response_template(DESCRIBE_SSL_POLICIES_TEMPLATE)
         return template.render(policies=policies)
 
-    @amzn_request_id
     def set_ip_address_type(self) -> str:
         arn = self._get_param("LoadBalancerArn")
         ip_type = self._get_param("IpAddressType")
@@ -733,7 +708,6 @@ class ELBV2Response(BaseResponse):
         template = self.response_template(SET_IP_ADDRESS_TYPE_TEMPLATE)
         return template.render(ip_type=ip_type)
 
-    @amzn_request_id
     def set_security_groups(self) -> str:
         arn = self._get_param("LoadBalancerArn")
         sec_groups = self._get_multi_param("SecurityGroups.member.")
@@ -743,7 +717,6 @@ class ELBV2Response(BaseResponse):
         template = self.response_template(SET_SECURITY_GROUPS_TEMPLATE)
         return template.render(sec_groups=sec_groups)
 
-    @amzn_request_id
     def set_subnets(self) -> str:
         arn = self._get_param("LoadBalancerArn")
         subnets = self._get_multi_param("Subnets.member.")
@@ -754,7 +727,6 @@ class ELBV2Response(BaseResponse):
         template = self.response_template(SET_SUBNETS_TEMPLATE)
         return template.render(subnets=subnet_zone_list)
 
-    @amzn_request_id
     def modify_load_balancer_attributes(self) -> str:
         arn = self._get_param("LoadBalancerArn")
         attrs = self._get_map_prefix(
@@ -766,7 +738,6 @@ class ELBV2Response(BaseResponse):
         template = self.response_template(MODIFY_LOADBALANCER_ATTRS_TEMPLATE)
         return template.render(attrs=all_attrs)
 
-    @amzn_request_id
     def describe_load_balancer_attributes(self) -> str:
         arn = self._get_param("LoadBalancerArn")
         attrs = self.elbv2_backend.describe_load_balancer_attributes(arn)
@@ -774,7 +745,6 @@ class ELBV2Response(BaseResponse):
         template = self.response_template(DESCRIBE_LOADBALANCER_ATTRS_TEMPLATE)
         return template.render(attrs=attrs)
 
-    @amzn_request_id
     def modify_target_group(self) -> str:
         arn = self._get_param("TargetGroupArn")
 
@@ -806,7 +776,6 @@ class ELBV2Response(BaseResponse):
         template = self.response_template(MODIFY_TARGET_GROUP_TEMPLATE)
         return template.render(target_group=target_group)
 
-    @amzn_request_id
     def modify_listener(self) -> str:
         arn = self._get_param("ListenerArn")
         port = self._get_param("Port")
@@ -828,7 +797,6 @@ class ELBV2Response(BaseResponse):
         template = self.response_template(MODIFY_LISTENER_TEMPLATE)
         return template.render(listener=listener)
 
-    @amzn_request_id
     def add_listener_certificates(self) -> str:
         arn = self._get_param("ListenerArn")
         certificates = self._get_list_prefix("Certificates.member")
@@ -839,7 +807,6 @@ class ELBV2Response(BaseResponse):
         template = self.response_template(ADD_LISTENER_CERTIFICATES_TEMPLATE)
         return template.render(certificates=certificate_arns)
 
-    @amzn_request_id
     def describe_listener_certificates(self) -> str:
         arn = self._get_param("ListenerArn")
         certificates = self.elbv2_backend.describe_listener_certificates(arn)
@@ -847,7 +814,6 @@ class ELBV2Response(BaseResponse):
         template = self.response_template(DESCRIBE_LISTENER_CERTIFICATES_TEMPLATE)
         return template.render(certificates=certificates)
 
-    @amzn_request_id
     def remove_listener_certificates(self) -> str:
         arn = self._get_param("ListenerArn")
         certificates = self._get_list_prefix("Certificates.member")
@@ -1578,40 +1544,6 @@ DESCRIBE_ATTRIBUTES_TEMPLATE = """<DescribeLoadBalancerAttributesResponse  xmlns
 </DescribeLoadBalancerAttributesResponse>
 """
 
-MODIFY_ATTRIBUTES_TEMPLATE = """<ModifyLoadBalancerAttributesResponse xmlns="http://elasticloadbalancing.amazonaws.com/doc/2015-12-01/">
-  <ModifyLoadBalancerAttributesResult>
-  <LoadBalancerName>{{ load_balancer.name }}</LoadBalancerName>
-    <LoadBalancerAttributes>
-      <AccessLog>
-        <Enabled>{{ attributes.access_log.enabled }}</Enabled>
-        {% if attributes.access_log.enabled %}
-        <S3BucketName>{{ attributes.access_log.s3_bucket_name }}</S3BucketName>
-        <S3BucketPrefix>{{ attributes.access_log.s3_bucket_prefix }}</S3BucketPrefix>
-        <EmitInterval>{{ attributes.access_log.emit_interval }}</EmitInterval>
-        {% endif %}
-      </AccessLog>
-      <ConnectionSettings>
-        <IdleTimeout>{{ attributes.connecting_settings.idle_timeout }}</IdleTimeout>
-      </ConnectionSettings>
-      <CrossZoneLoadBalancing>
-        <Enabled>{{ attributes.cross_zone_load_balancing.enabled }}</Enabled>
-      </CrossZoneLoadBalancing>
-      <ConnectionDraining>
-        {% if attributes.connection_draining.enabled %}
-        <Enabled>true</Enabled>
-        <Timeout>{{ attributes.connection_draining.timeout }}</Timeout>
-        {% else %}
-        <Enabled>false</Enabled>
-        {% endif %}
-      </ConnectionDraining>
-    </LoadBalancerAttributes>
-  </ModifyLoadBalancerAttributesResult>
-  <ResponseMetadata>
-    <RequestId>{{ request_id }}</RequestId>
-  </ResponseMetadata>
-</ModifyLoadBalancerAttributesResponse>
-"""
-
 CREATE_LOAD_BALANCER_POLICY_TEMPLATE = """<CreateLoadBalancerPolicyResponse xmlns="http://elasticloadbalancing.amazonaws.com/doc/2015-12-01/">
   <CreateLoadBalancerPolicyResult/>
   <ResponseMetadata>
