@@ -477,18 +477,22 @@ class IoTResponse(BaseResponse):
         self.iot_backend.attach_policy(policy_name=policy_name, target=target)
         return json.dumps(dict())
 
-    def dispatch_attached_policies(
-        self, request: Any, full_url: str, headers: Any
+    @staticmethod
+    def dispatch_attached_policies(  # type: ignore
+        request: Any, full_url: str, headers: Any
     ) -> TYPE_RESPONSE:
+        response = IoTResponse()
         # This endpoint requires specialized handling because it has
         # a uri parameter containing forward slashes that is not
         # correctly url encoded when we're running in server mode.
         # https://github.com/pallets/flask/issues/900
-        self.setup_class(request, full_url, headers)
-        self.querystring["Action"] = ["ListAttachedPolicies"]
-        target = self.path.partition("/attached-policies/")[-1]
-        self.querystring["target"] = [unquote(target)] if "%" in target else [target]
-        return self.call_action()
+        response.setup_class(request, full_url, headers)
+        response.querystring["Action"] = ["ListAttachedPolicies"]
+        target = response.path.partition("/attached-policies/")[-1]
+        response.querystring["target"] = (
+            [unquote(target)] if "%" in target else [target]
+        )
+        return response.call_action()
 
     def list_attached_policies(self) -> str:
         principal = self._get_param("target")
