@@ -3,10 +3,11 @@ import re
 from collections import defaultdict
 from typing import Any, Dict, Tuple, Union
 
-from moto.core.responses import BaseResponse
+from moto.core.responses import TYPE_RESPONSE, BaseResponse
 from moto.core.utils import camelcase_to_underscores
-from .models import sns_backends, SNSBackend
+
 from .exceptions import InvalidParameterValue, SNSNotFoundError
+from .models import SNSBackend, sns_backends
 from .utils import is_e164
 
 
@@ -180,9 +181,9 @@ class SNSResponse(BaseResponse):
                 attributes["KmsMasterKeyId"] = topic.kms_master_key_id
             if topic.fifo_topic == "true":
                 attributes["FifoTopic"] = topic.fifo_topic
-                attributes[
-                    "ContentBasedDeduplication"
-                ] = topic.content_based_deduplication
+                attributes["ContentBasedDeduplication"] = (
+                    topic.content_based_deduplication
+                )
             response = {
                 "GetTopicAttributesResponse": {
                     "GetTopicAttributesResult": {"Attributes": attributes},
@@ -732,7 +733,13 @@ class SNSResponse(BaseResponse):
         aws_account_ids = self._get_multi_param("AWSAccountId.member.")
         action_names = self._get_multi_param("ActionName.member.")
 
-        self.backend.add_permission(topic_arn, label, aws_account_ids, action_names)
+        self.backend.add_permission(
+            region_name=self.region,
+            topic_arn=topic_arn,
+            label=label,
+            aws_account_ids=aws_account_ids,
+            action_names=action_names,
+        )
 
         template = self.response_template(ADD_PERMISSION_TEMPLATE)
         return template.render()
@@ -795,6 +802,14 @@ class SNSResponse(BaseResponse):
 
         return self.response_template(UNTAG_RESOURCE_TEMPLATE).render()
 
+    @staticmethod
+    def serve_pem(request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[misc]
+        sns = SNSResponse()
+        sns.setup_class(request, full_url, headers)
+        key_name = full_url.split("/")[-1]
+        key = sns.backend._message_public_keys[key_name]
+        return 200, {}, key
+
 
 CREATE_TOPIC_TEMPLATE = """<CreateTopicResponse xmlns="http://sns.amazonaws.com/doc/2010-03-31/">
      <CreateTopicResult>
